@@ -1,3 +1,9 @@
+"""
+$description Live TV and video on-demand service owned by Paramount Streaming.
+$url pluto.tv
+$type live, vod
+"""
+
 import logging
 import re
 from urllib.parse import parse_qs, urljoin
