@@ -1,3 +1,11 @@
+"""
+$description Live TV channels from RSI and SRF, operations of SRG SSR, a Swiss public broadcaster.
+$url srf.ch
+$url rsi.ch
+$type live
+$region Switzerland
+"""
+
 import logging
 import re
 from urllib.parse import parse_qsl, urlparse, urlunparse
