@@ -1,3 +1,12 @@
+"""
+$description Live TV channels and video on-demand service from TV4, a Swedish free-to-air broadcaster.
+$url tv4play.se
+$url fotbollskanalen.se
+$type live, vod
+$region Sweden
+$notes Only non-premium streams are supported
+"""
+
 import logging
 import re
 from urllib.parse import urljoin
