@@ -7,7 +7,7 @@ from threading import Event, Thread, current_thread
 from typing import Any, Optional
 
 from streamlink.buffers import RingBuffer
-from streamlink.stream.stream import StreamIO
+from streamlink.stream.stream import Stream, StreamIO
 
 log = logging.getLogger(__name__)
 
@@ -56,7 +56,11 @@ class SegmentedStreamWorker(AwaitableMixin, Thread):
     writer thread.
     """
 
-    def __init__(self, reader, **kwargs):
+    reader: "SegmentedStreamReader"
+    writer: "SegmentedStreamWriter"
+    stream: "Stream"
+
+    def __init__(self, reader: "SegmentedStreamReader", **kwargs):
         super().__init__(daemon=True, name=f"Thread-{self.__class__.__name__}")
         self.closed = False
         self.reader = reader
@@ -100,7 +104,10 @@ class SegmentedStreamWriter(AwaitableMixin, Thread):
     and finally writing the data to the buffer.
     """
 
-    def __init__(self, reader, size=20, retries=None, threads=None, timeout=None):
+    reader: "SegmentedStreamReader"
+    stream: "Stream"
+
+    def __init__(self, reader: "SegmentedStreamReader", size=20, retries=None, threads=None, timeout=None):
         super().__init__(daemon=True, name=f"Thread-{self.__class__.__name__}")
         self.closed = False
         self.reader = reader
@@ -120,7 +127,7 @@ class SegmentedStreamWriter(AwaitableMixin, Thread):
         self.timeout = timeout
         self.threads = threads
         self.executor = CompatThreadPoolExecutor(max_workers=self.threads)
-        self.futures = queue.Queue(size)
+        self.futures: queue.Queue[Future] = queue.Queue(size)
 
     def close(self):
         """Shuts down the thread, its executor and closes the reader (worker thread and buffer)."""
@@ -210,10 +217,14 @@ class SegmentedStreamReader(StreamIO):
     __worker__ = SegmentedStreamWorker
     __writer__ = SegmentedStreamWriter
 
-    def __init__(self, stream, timeout=None):
+    worker: "SegmentedStreamWorker"
+    writer: "SegmentedStreamWriter"
+    stream: "Stream"
+
+    def __init__(self, stream: "Stream", timeout=None):
         super().__init__()
-        self.session = stream.session
         self.stream = stream
+        self.session = stream.session
         self.timeout = timeout or self.session.options.get("stream-timeout")
 
         buffer_size = self.session.get_option("ringbuffer-size")
@@ -236,6 +247,8 @@ class SegmentedStreamReader(StreamIO):
         if current is not self.writer:  # pragma: no branch
             self.writer.join(timeout=self.timeout)
 
+        super().close()
+
     def read(self, size):
         return self.buffer.read(
             size,
