@@ -1,6 +1,5 @@
 import os
 import signal
-import warnings
 
 import pytest
 
@@ -19,22 +18,8 @@ signal.signal(signal.SIGTERM, signal.default_int_handler)
 pytest.register_assert_rewrite("tests.plugins")
 
 
-def catch_warnings(record=False, module=None):
-    def _catch_warnings_wrapper(f):
-        def _catch_warnings(*args, **kwargs):
-            with warnings.catch_warnings(record=True, module=module) as w:
-                if record:
-                    return f(*(args + (w,)), **kwargs)
-                else:
-                    return f(*args, **kwargs)
-
-        return _catch_warnings
-
-    return _catch_warnings_wrapper
-
-
 windows_only = pytest.mark.skipif(os.name != "nt", reason="test only applicable on Windows")
 posix_only = pytest.mark.skipif(os.name != "posix", reason="test only applicable on a POSIX OS")
 
 
-__all__ = ['catch_warnings', 'windows_only', 'posix_only']
+__all__ = ["windows_only", "posix_only"]
