@@ -6,5 +6,6 @@ class TestPluginCanHandleUrlORFTVThek(PluginCanHandleUrl):
     __plugin__ = ORFTVThek
 
     should_match = [
-        'http://tvthek.orf.at/live/Wetter/13953206',
+        "https://tvthek.orf.at/live/Christine-Lavant-Preis-2021/14139354",
+        "https://tvthek.orf.at/profile/Aktuell-nach-eins/13887636/Aktuell-nach-eins/14107576",
     ]
