@@ -6,14 +6,15 @@ class TestPluginCanHandleUrlTVRPlus(PluginCanHandleUrl):
     __plugin__ = TVToya
 
     should_match = [
-        "https://tvtoya.pl/live",
-        "http://tvtoya.pl/live",
+        "http://tvtoya.pl/player/live",
+        "https://tvtoya.pl/player/live",
     ]
 
     should_not_match = [
-        "https://tvtoya.pl",
         "http://tvtoya.pl",
-        "http://tvtoya.pl/other-page",
         "http://tvtoya.pl/",
+        "http://tvtoya.pl/live",
+        "https://tvtoya.pl",
         "https://tvtoya.pl/",
+        "https://tvtoya.pl/live",
     ]
